@@ -22,6 +22,14 @@
     #include<netinet/in.h>
   #endif
 
+  #ifndef _NETDB_H
+    #include<netdb.h>
+  #endif
+
+  #ifndef _UNISTD_H_
+    #include<unistd.h>
+  #endif
+
 
   #define CL_VER "almemsys-1.0.8"
 
@@ -53,6 +61,7 @@
   int mem_count(char [], char);
   int mem_tcount(char [], char);
   int char_count(char [], char);
+  int rm_char(char [], char);
   int char_point(char *, char, int);
   int char_get(char *, char *, char, int);
   int clean_mem(char [], char, int);
@@ -70,6 +79,8 @@
   int ch_int(char *);
   int ch_int2(char *);
   int ch_int3(char *, char);
+  int ch_int_v6(char *);
+  int ch_int_v4(char *);
   char * ch_char(char *, char *);
   int self_memcmp(char *, char *);
   int alversion(void);
@@ -94,6 +105,7 @@
 
   /* --- socket --- */
   int socket_reada(int, char *, int);
+  int socket_readas(int, char *, int, int, int);
   int socket_reads(int, char * , int, int);
   int socket_sends(int, char *, int, char);
   int socket_send(int, char *, int);
@@ -125,6 +137,11 @@
   char * message_id(char * backdata, char * name, char * domain);
 
   /* --- socket --- */
+  int socket_bind46(struct addrinfo * hints, char * addr, char * port, int * ls, int maxsock);
+  char * socket_accept46(char * ipdate, fd_set rfd, int * s, int smax, int sockmax, int * sk, int * net);
+  int socket_accept46rfd(fd_set * rfd, int * s, int smax);
+  int socket_connect46(struct addrinfo * hints, char * ip, char * port, int * sk);
+
   int socket_connect(struct sockaddr_in *, int, char [], int *);
   int socket_bind(struct sockaddr_in *, int, char *, int *);
   int socket_accept(struct sockaddr_in *, int *, int *);
