@@ -18,13 +18,25 @@ sto =0;
 count = 0;
 * ret = 0;
 
+if(data == NULL){
+   data = (char *)calloc(BUF_LEN, sizeof(char));
+   }
+else{
+   data = null_free(data);
+   }
+
+if(swap == NULL){
+   return data;
+   }
+
+
 count  = delim_count(swap, delim, target, &sta, &sto);
 #ifdef MAIL_DEBUG
 printf("DELIM 1 %d -> %d %d\n", sta, sto, count);
 #endif
 if(count > 0 && sta <= sto){
    data = (char *)realloc(data, (count + 2) * (sizeof(char)));
-   memcount_cpm(data, swap, sta, sto);
+   memcount_cpm(data, swap, sta, sto, count);
    }
 else{
    data = (char *)realloc(data, 5 * (sizeof(char)));
