@@ -7,11 +7,10 @@ char * null_free(char * data)
 int len;
 len = (int)strlen(data);
 
-
 if(0 < len){
 
    #ifdef NULL_FREEBUG
-   printf("null_free(%d)\n", len);
+   printf("null_free(%d) %s\n", len, data);
    #endif
 
    memset(data, 0x00, len);
