@@ -9,7 +9,7 @@
 // char * safe_base64(char *, int, int);
  
 
-char * safe_base64(char * data, int cat)
+char * safe_base64(char * data)
 {
 char * swap;
 int max;
@@ -18,7 +18,7 @@ max = (int)strlen(data);
 
 if(max > 0){
    swap = (char *)calloc((max * 2), (int)sizeof(char));
-   base64(data, max, swap, cat);
+   base64(data, max, swap);
    data = safe_memcpy(data, swap, BUF_MAX);
    free(swap);
    }
