@@ -20,8 +20,23 @@
 char * safe_strncat(char * buf, char * newdata, int max_len)
 {
 int plen = 0;
-int buf_count = (int)strlen(buf);
-int newdata_count = (int)strlen(newdata);
+int newdata_count;
+int buf_count;
+
+if(newdata == NULL){
+   return buf;
+   }
+else if(newdata[0] == (char)0x00){
+   return buf;
+   }
+
+newdata_count = (int)strlen(newdata);
+
+if(buf == NULL){
+   buf = (char *)calloc(BUF_LEN, sizeof(char));
+   }
+
+buf_count = (int)strlen(buf);
 
 if(buf_count < max_len){
    if(max_len <= (newdata_count + buf_count)){
