@@ -113,6 +113,22 @@ ch8 = out_bit(in8, ch8, 8);
 
 printf("in_bit() out_bit(): <%d><%s><%d>\n", in8, ch8, (int)in_bit(ch8, 8));
 
+taro = safe_memcpy(taro, "121212121212121212", 1000);
+printf("taro 1: <%s>\n", taro);
+ret = rm_char(taro, '1');
+printf("taro 2: <%s>%d\n\n", taro, ret);
+
+taro = safe_memcpy(taro, "121212121212121212", 1000);
+printf("taro 1: <%s>\n", taro);
+ret = rm_char(taro, '2');
+printf("taro 2: <%s>%d\n\n", taro, ret);
+
+taro = safe_memcpy(taro, "101010101001", 1000);
+printf("taro 1: <%s>\n", taro);
+ret = rm_char(taro, '0');
+printf("taro 2: <%s>%d\n\n", taro, ret);
+
+
 
 return 0;
 }
