@@ -40,7 +40,7 @@ print("\n");
 print(date("Y m d g i s A"));
 print("\n");
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -55,14 +55,14 @@ if(0 == strlen($BNAME2)){
    exit;
    }
 
-$result=pg_query($conn, "select * from userblock where bname='$BNAME'");
+$result=db_query($conn, "select * from userblock where bname='$BNAME'");
 if(!$result){
    print("NG bud query set\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
-    $CNAMEDEF = enco_rtrim(pg_fetch_Result($result, $s, cname));
+    $CNAMEDEF = enco_rtrim(db_fetch_Result($result, $s, cname));
     print("OK ư֥åϿƤ륯饤Ȥ $CNAMEDEF Ǥ\n");
     }
 else{
@@ -70,39 +70,39 @@ else{
    exit;
    }
 
-$result = pg_query($conn, "select * from userblock where bname='$BNAME'");
+$result = db_query($conn, "select * from userblock where bname='$BNAME'");
 if(!$result){
    print("bud query set\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("NG ֥å̾DBˤޤ\n");
    exit;
    }
 if($num > 0){
    print("ƻ֥å̾ѹޤ\n");
-   $result = pg_query($conn, "update userblock set
+   $result = db_query($conn, "update userblock set
      bname='$BNAME2' where bname='$BNAME'");
    if(!$result){
       print("NG ѹޤ\n");
       exit;
       }
    print("Ϣƻѹޤ\n");
-   $result = pg_query($conn, "update monitor set
+   $result = db_query($conn, "update monitor set
      free4='$BNAME2' where free4='$BNAME'");
    if(!$result){
       print("NG ޤ\n");
       exit;
       }
-   pg_free_result($result);
+   db_free_result($result);
    }
 
 
 // --- list file upload --- // 
 list_file_upload($CNAMEDEF, $GEN);
 
-pg_Close($conn);
+db_Close($conn);
 
 ?>
 
