@@ -303,6 +303,9 @@ echo "ץȥ";
 echo "<select size=1 name=PROTO>";
 echo "<option value=>NON";
 echo "<option value=SMTP>SMTP";
+echo "<option value=FTP>FTP";
+echo "<option value=POP>POP";
+echo "<option value=SSH>SSH";
 echo "<option value=URL>URL";
 echo "<option value=SSL>SSL";
 echo "<option value=DHW>DHW";
