@@ -9,8 +9,6 @@ if(0 > ninsyou_check(3)){
    }
 
 
-
-
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
 echo "<HTML>";
 echo "<HEAD>";
@@ -55,7 +53,7 @@ $SE="LIKE";
 $EE="=";
 
 // ----- DB ³ ----//
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -156,15 +154,15 @@ if(0 == strlen($block_new)){     // ֥å̵
       $select_data = $select_data . " free4='$free4'";
 
       print("$free4 ˴ޤޤƻ֥åĴޤ\n");
-      $result = pg_query($conn, "select * from userblock where bname='$free4'");
+      $result = db_query($conn, "select * from userblock where bname='$free4'");
       if(!$result){
          print("bud query set\n");
          exit;
          }
-      $num = pg_num_rows($result);
+      $num = db_num_rows($result);
       if($num > 0){
          while($s < $num){
-            $NEW_CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
+            $NEW_CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
             print("ƻ֥åѹ򤵤Ƥޤ   $NEW_CNAME $free4\n");
             $select_data = $select_data . ", ";
             $select_data = $select_data . " cname='$NEW_CNAME'";
@@ -178,7 +176,7 @@ if(0 == strlen($block_new)){     // ֥å̵
          print("ƻ֥åѹ򤵤ƤޤƤޤ $free4\n");
          exit;
          } 
-      pg_free_result($result);
+      db_free_result($result);
       }
    }
 
@@ -220,12 +218,12 @@ if(0 == strlen($block_new)){     // ֥å̵
 
 
    // --- ѹCNAMEꥹ ----//
-   $result = pg_query($conn, "select distinct(cname) from monitor $select_get");
+   $result = db_query($conn, "select distinct(cname) from monitor $select_get");
    if(!$result){
       print("NG bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num <= 0){
       print("no data\n");
       exit;
@@ -233,7 +231,7 @@ if(0 == strlen($block_new)){     // ֥å̵
    else{
       $cname_count =0;
       while($cname_count < $num){
-         $cname_data[$cname_count]  = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
+         $cname_data[$cname_count]  = enco_rtrim(db_fetch_Result($result, $cname_count, cname));
          print("ѹ饤ȡ $cname_data[$cname_count]  ֹ桡 $cname_count");
          print("\n");
          $cname_count++;
@@ -250,13 +248,13 @@ if(0 == strlen($block_new)){     // ֥å̵
       exit;
       }
    else{
-      $result = pg_query($conn, "$select_data");
+      $result = db_query($conn, "$select_data");
       print("ƻѹ夦Ǥ\n");
       if(!$result){
          print("NG bud query $select_data\n");
          exit;
          }
-      $num = pg_num_rows($result);
+      $num = db_num_rows($result);
       if($num < 0){
          print("NG ƻ֥å꤬ѹƤޤ\n");
          exit;
@@ -302,21 +300,21 @@ else{  // ֥åä
    print("ǡѹϹԤޤ\n");
 
    // ֥å̾бCNAME򸡺
-   $result=pg_query($conn,"select distinct(cname) from userblock where bname='$block_new';");
+   $result=db_query($conn,"select distinct(cname) from userblock where bname='$block_new';");
    if(!$result){
       print("bname , canem select , bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num > 0){
-      $cname_new = enco_rtrim(pg_fetch_Result($result, 0, cname));
+      $cname_new = enco_rtrim(db_fetch_Result($result, 0, cname));
       print("б륯饤̾ $cname_new Ǥ\n");
       }
    else{
       print("$block_new б륯饤̾¸ߤޤ\n");
       exit;
       }
-   pg_free_result($result);
+   db_free_result($result);
    $num = 0;
 
    //------ DBѹ -----//
@@ -328,13 +326,13 @@ else{  // ֥åä
 
       $select_get_data = "select * from monitor " . $select_get;
 
-      $result = pg_query($conn, "$select_get_data");
+      $result = db_query($conn, "$select_get_data");
       print("Ϥޤ\n");
       if(!$result){
          print("NG bud query $select_get_data\n");
          exit;
          }
-      $num = pg_num_rows($result);
+      $num = db_num_rows($result);
       if($num <= 0){
          print("NG ƻ֥å꤬ѹƤޤ\n");
          exit;
@@ -343,38 +341,55 @@ else{  // ֥åä
          $ss = 0;
          while($ss < $num){
 
-            if(0 == strlen($come)){ $COME = enco_rtrim(pg_fetch_Result($result, $ss, come)); }
+            if(0 == strlen($come)){ $COME = enco_rtrim(db_fetch_Result($result, $ss, come)); }
             else{ $COME = $come; }
-            if(0 == strlen($monitor)){ $MONITOR = enco_rtrim(pg_fetch_Result($result, $ss, monitor)); }
+            if(0 == strlen($monitor)){ $MONITOR = enco_rtrim(db_fetch_Result($result, $ss, monitor)); }
             else{ $MONITOR = $monitor; }
-            if(0 == strlen($sign)){ $SIGN = enco_rtrim(pg_fetch_Result($result, $ss, sign)); }
+            if(0 == strlen($sign)){ $SIGN = enco_rtrim(db_fetch_Result($result, $ss, sign)); }
             else{ $SIGN = $sign; }
-            if(0 == strlen($proto)){ $PROTO = enco_rtrim(pg_fetch_Result($result, $ss, proto)); }
+            if(0 == strlen($proto)){ $PROTO = enco_rtrim(db_fetch_Result($result, $ss, proto)); }
             else{ $PROTO = $proto; }
-            if(0 == strlen($com)){ $COM = enco_rtrim(pg_fetch_Result($result, $ss, com)); }
+            if(0 == strlen($com)){ $COM = enco_rtrim(db_fetch_Result($result, $ss, com)); }
             else{ $COM = $com; }
-            if(0 == strlen($cip)){ $CIP = enco_rtrim(pg_fetch_Result($result, $ss, cip)); }
+            if(0 == strlen($cip)){ $CIP = enco_rtrim(db_fetch_Result($result, $ss, cip)); }
             else{ $CIP = $cip; }
-            if(0 == strlen($port)){ $PORT = enco_rtrim(pg_fetch_Result($result, $ss, port)); }
+            if(0 == strlen($port)){ $PORT = enco_rtrim(db_fetch_Result($result, $ss, port)); }
             else{ $PORT = $port; }
-            if(0 == strlen($wtime)){ $WTIME = enco_rtrim(pg_fetch_Result($result, $ss, wtime)); }
+            if(0 == strlen($wtime)){ $WTIME = enco_rtrim(db_fetch_Result($result, $ss, wtime)); }
             else{ $WTIME= $wtime; }
-            if(0 == strlen($pinfo)){ $PINFO = enco_rtrim(pg_fetch_Result($result, $ss, pinfo)); }
+            if(0 == strlen($pinfo)){ $PINFO = enco_rtrim(db_fetch_Result($result, $ss, pinfo)); }
             else{ $PINFO = $pinfo; }
-            if(0 == strlen($prino)){ $PRINO = enco_rtrim(pg_fetch_Result($result, $ss, prino)); }
+            if(0 == strlen($prino)){ $PRINO = enco_rtrim(db_fetch_Result($result, $ss, prino)); }
             else{ $PRINO = $prino; }
-            if(0 == strlen($free1)){ $FREE1 = enco_rtrim(pg_fetch_Result($result, $ss, free1)); }
+            if(0 == strlen($free1)){ $FREE1 = enco_rtrim(db_fetch_Result($result, $ss, free1)); }
             else{ $FREE1 = $free1; }
-            if(0 == strlen($free2)){ $FREE2 = enco_rtrim(pg_fetch_Result($result, $ss, free2)); }
+            if(0 == strlen($free2)){ $FREE2 = enco_rtrim(db_fetch_Result($result, $ss, free2)); }
             else{ $FREE2 = $free2; }
-            if(0 == strlen($free3)){ $FREE3 = enco_rtrim(pg_fetch_Result($result, $ss, free3)); }
+            if(0 == strlen($free3)){ $FREE3 = enco_rtrim(db_fetch_Result($result, $ss, free3)); }
             else{ $FREE3 = $free3; }
 
-//          $UNO = enco_rtrim(pg_fetch_Result($result, $ss, uno));
+//          $UNO = enco_rtrim(db_fetch_Result($result, $ss, uno));
 
 print("UNO=$UNO, $COME, $MONITOR, $SIGN, $PROTO, $COM, $CIP, $PORT, $WTIME, $PINFO, $PRINO, $block_new, $cname_new\n");
 
-            $result2 = pg_query($conn, "insert into monitor values (
+            $result2 = db_query($conn, "insert into monitor
+             (
+             come,
+             cname,
+             monitor,
+             sign,
+             proto,
+             com,
+             cip,
+             port,
+             wtime,
+             pinfo,
+             prino,
+             free1,
+             free2,
+             free3,
+             free4
+             ) values (
              '$COME',
              '$cname_new',
              '$MONITOR',
@@ -395,14 +410,14 @@ print("UNO=$UNO, $COME, $MONITOR, $SIGN, $PROTO, $COM, $CIP, $PORT, $WTIME, $PIN
                print("bud query set\n");
                exit;
                }
-            pg_free_result($result2);
+            db_free_result($result2);
 
 
             $ss++;
             }
          $ss = 0;
          }
-      pg_free_result($result);
+      db_free_result($result);
       }
 
    print("OK DBѹϴλޤ\n");
@@ -419,7 +434,7 @@ print("UNO=$UNO, $COME, $MONITOR, $SIGN, $PROTO, $COM, $CIP, $PORT, $WTIME, $PIN
 
 
 
-pg_Close($conn);
+db_Close($conn);
 
 ?>
 
