@@ -322,6 +322,9 @@ elseif($step1 > 0 && 0 == strcmp($MONITOR, "PORT") && $step2 <= 0){
    print("<option value=URL>URLơ");
    print("<option value=SSL>SSLURLơ");
    print("<option value=SMTP>SMTPơ");
+   print("<option value=FTP>FTPơ");
+   print("<option value=POP>POPơ");
+   print("<option value=SSH>SSHơ");
    print("<option value=SNTP>NTPФȤλֺǧ");
    print("<option value=HOST>DNS̾ǧ");
    print("</select>");
