@@ -36,7 +36,7 @@ if((fp = fopen(argv[1], "r"))!=NULL){
    close(fd);
    }
 
-stat = file_comp(chB);
+stat = file_comp(chB, "");
 
 free(chB);
 
