@@ -124,7 +124,10 @@
 #define ERR_MAIL_2 "Υ֥å˳Ƥ줿Ļ֤äƤޤ "
 #define ERR_MAIL_3 "Ļܤ¿١ιԤĻ뤵Ƥޤ "
 
-
+#define DHW_ERR1 "DHW顼֤ޤ! "
+#define DHW_ERR2 "DHW֤ʸʤΤǤʥޥɤǧ  "
+#define DHW_ERR3 "DHWϥ顼֤ޤǤ "
+#define DHW_ERR4 "DHW֤ͤ³ڤޤDHW˥ॢȤ⤷ޤ "
 
 #endif
 
