@@ -50,10 +50,6 @@ int print_conf(void)
    fprintf(stdout,"-- CRON_ONOFF     (enable cron mode 1)    = %d\n", gd.cron_onoff);
    fprintf(stdout,"Version %s\n", CL_VAR);
 
-char * mid_max ="MID_MAX";
-char * thread_len="THREAD_LEN";
-char * mid_int="MID_INT";
-
 
 return 0;
 }
