@@ -22,11 +22,12 @@
 
 // #define RESOLV_DEBUG
 
-char * resolvename_sk(char * backdata, char *name, int timeout, unsigned long * ret, char * dns_ip, int * stat)
+char * resolvename_sk(char * backdata, char *name, int timeout, unsigned long * ret, char * dns_ip, int * stat, char type)
 {
 
 // char * scan_dns_connect(int, char *, char *, char *, int, int *);
-backdata = scan_dns_connect(53, dns_ip, name, backdata, timeout, stat);
+// backdata = scan_dns_connect(53, dns_ip, name, backdata, timeout, stat);
+backdata = scan_dns_connect(53, dns_ip, name, backdata, timeout, stat, type);
 swap_mem(backdata, '\n', 0x00);
 
 #ifdef RESOLV_DEBUG
