@@ -132,9 +132,9 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    if(resolv_ret < 0){
-      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret, '4');
       fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
       }
    }
@@ -161,7 +161,7 @@ printf("ICMP: scan_icmp(1): ICMP host<%s> ip<%s>\n", ip_addr, ip_addr2);
 // RAW socketの生成
 if((send_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    backdata=safe_sprintf(backdata, BUF_MAX,
-    "IP=%s %s", ip_addr, ICMP_1);
+    "HOST=%s IP=%s %s", ip_addr, ip_addr2, ICMP_1);
    #ifdef ICMP_BUG
    printf("ICMP: scan_icmp(2): SOCKET CREATE %s\n", backdata);
    #endif
@@ -172,8 +172,7 @@ if((send_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
 // ICMPパケットの生成と送信
 make_icmp8_packet((struct icmp *)(long int)send_buff, 72, i);
 if(sendto(send_sk, (char *)&send_buff, 72, 0, (struct sockaddr *)(long int)&send_addr, sizeof(send_addr)) < 0){
-   backdata=safe_sprintf(backdata, BUF_MAX,"IP=%s %s",
-    ip_addr, ICMP_2);
+   backdata=safe_sprintf(backdata, BUF_MAX,"HOST=%s IP=%s %s", ip_addr, ip_addr2, ICMP_2);
    #ifdef ICMP_BUG
    printf("ICMP: scan_icmp(3): SEND RAW SOCKET %s\n", backdata);
    #endif
@@ -197,8 +196,7 @@ while(1){
 
    // FDに変化があった場合はrecvする
    if(recvfrom(send_sk, recv_buff, 1024, 0, NULL, NULL) < 0){
-      backdata=safe_sprintf(backdata, BUF_MAX,"IP=%s %s",
-       ip_addr, ICMP_3);
+      backdata=safe_sprintf(backdata, BUF_MAX,"HOST=%s IP=%s %s", ip_addr, ip_addr2, ICMP_3);
       #ifdef ICMP_BUG
       printf("ICMP: scan_icmp(4): RECV RAW SOCKET %s\n", backdata);
       #endif
@@ -307,7 +305,7 @@ while(1){
 
 rtt = tv.tv_sec*1000.0 + tv.tv_usec/1000.0;
 backdata=safe_sprintf(backdata,BUF_MAX,
- "IP=%s :RTT=%7.4fms %s", ip_addr, rtt, ICMP_13);
+ "HOST=%s IP=%s :RTT=%7.4fms %s", ip_addr, ip_addr2, rtt, ICMP_13);
 #ifdef ICMP_BUG
 printf("ICMP: scan_icmp(12): LAST %s\n", backdata);
 #endif
