@@ -69,8 +69,7 @@ printf("URL_BUG: scan_url_connect(): data %s dom %s pass %s port %d\n", url_data
 
 if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
    fprintf(stderr,"scan_url URL=%s Port=%d tcp %s", url_data, port, SOCK_1);
-   backdata=safe_sprintf(backdata, BUF_MAX,
-    "URL=%s Port=%d tcp %s", url_data, port, SOCK_1);
+   backdata=safe_sprintf(backdata, BUF_MAX, "URL=%s Port=%d: %s", url_data, port, SOCK_1);
    #ifdef URL_BUG
    printf("URL_BUG: scan_url_connect(1): NOT CLEATE SOCKETS %s\n", backdata);
    #endif
@@ -90,9 +89,9 @@ if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
    backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
    }
 else{
-   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret, '4');
    if(resolv_ret < 0){
-      backdata = resolvename_sk(backdata, url_dom, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      backdata = resolvename_sk(backdata, url_dom, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret, '4');
       fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", url_dom, backdata);
       }
    }
@@ -102,7 +101,7 @@ my_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
 // backdata=safe_sprintf(backdata,BUF_MAX,"%s %s %d\n", SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr);
-   backdata=safe_sprintf(backdata,BUF_MAX,"%s %s\n", SOCK_2, url_dom);
+   backdata=safe_sprintf(backdata,BUF_MAX,"%s: %s", url_dom, SOCK_2);
    #ifdef URL_BUG
    printf("URL_BUG: scan_url_connect(2):  NOT RESOLV NAME %s\n", backdata);
    #endif
@@ -126,8 +125,7 @@ re = connect(sk, (struct sockaddr *)(long)&my_addr, sizeof(my_addr));
 if(re >= 0){
    // 非同期通信から同期通信に
    fcntl(sk, F_SETFL, 0);
-   backdata=safe_sprintf(backdata,BUF_MAX,
-    "URL=%s Port=%d %s", url_data, port, SOCK_5);
+   backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_5);
    #ifdef URL_BUG
    printf("URL_BUG: scan_url_connect(4): CONNECT SUCCESS %s\n", backdata);
    #endif
@@ -144,8 +142,7 @@ if(errno == EINPROGRESS){
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
       // select の異常終了
       if(retval < 0){
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_data, port, SOCK_15, SOCK_5);
+         backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_15);
          #ifdef URL_BUG
          printf("URL_BUG: scan_url_connect(4): select error BREAK- %d - %s\n", retval, backdata);
          #endif
@@ -158,8 +155,7 @@ if(errno == EINPROGRESS){
 
       // select のタイムアウト
       else if(retval == 0){
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s %s", url_data, port, SOCK_16, SOCK_5);
+         backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_16);
          #ifdef URL_BUG
          printf("URL_BUG: scan_url_connect(5): select time out BREAK- %d - %s\n", retval, backdata);
          #endif
@@ -173,8 +169,7 @@ if(errno == EINPROGRESS){
       else{
          // 非同期通信から同期通信に
          fcntl(sk, F_SETFL, 0);
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_data, port, SOCK_3);
+         backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_3);
          #ifdef URL_BUG
          printf("URL_BUG: scan_url_connect(6): select time succes BREAK-%d- %s\n", retval, backdata);
          #endif
@@ -189,8 +184,7 @@ if(errno == EINPROGRESS){
 
    // ソケットに関するペンディングエラーを返す
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
-      backdata=safe_sprintf(backdata,BUF_MAX,
-       "URL=%s Port=%d %s", url_data, port, SOCK_13);
+      backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_13);
       #ifdef URL_BUG
       printf("URL_BUG: scan_url_connect(): getsockopt(7) Errors!\n");
       #endif
@@ -202,7 +196,7 @@ if(errno == EINPROGRESS){
       // エラーがある場合
       if(retval){
          backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s: TCP %s", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
+          "URL=%s IP=%s Port=%d %s: %s", url_data, ip_addr, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef URL_BUG
          printf("URL_BUG: scan_url_connect(8): 1 SO_ERROR %d %s\n", retval, backdata);
          #endif
@@ -213,8 +207,7 @@ if(errno == EINPROGRESS){
 
       // エラーが無い場合
       else{
-         backdata=safe_sprintf(backdata,BUF_MAX,
-          "URL=%s Port=%d %s", url_data, port, SOCK_3);
+         backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_3);
          self_set_request(senddata, url_dom, url_pass, BUF_LEN);
          #ifdef URL_BUG
          printf("URL_BUG: scan_url_connect(9): set_request*send-%s- %s\n", senddata, backdata);
@@ -234,8 +227,7 @@ if(errno == EINPROGRESS){
             retval = select(sk + 1, &rfds, NULL, NULL, &tv);
             // select 異常終了
             if(retval < 0){
-               backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_data, port, SOCK_15, URL_2);
+               backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, URL_2);
                #ifdef URL_BUG
                printf("URL_BUG: scan_url_connect(10): select error %s\n", backdata);
                #endif 
@@ -247,8 +239,7 @@ if(errno == EINPROGRESS){
                }
             // select のタイムアウト
             else if(retval == 0){
-               backdata=safe_sprintf(backdata,BUF_MAX,
-                "URL=%s Port=%d %s %s", url_data, port, SOCK_16, URL_3);
+               backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, URL_3);
                #ifdef URL_BUG
                printf("URL_BUG: scan_url_connect(11): select timed out %s\n", backdata); 
                #endif 
@@ -259,16 +250,16 @@ if(errno == EINPROGRESS){
                return backdata;
                }
             else{
+               // 非同期通信から同期通信
+               fcntl(sk, F_SETFL, 0);
 //             dcount = recv(sk, recvdata, BUF_LEN, 0);
-               dcount = socket_reada(sk, recvdata, BUF_LEN);
+               dcount = socket_readas(sk, recvdata, BUF_LEN, timeout, 1);
                #ifdef URL_BUG
                printf("URL_BUG: scan_url_connect(12): select succes. recv data %s<%d>\n", recvdata, dcount);
                #endif
                // 受信量が異常
                if(dcount < 1){
-                  backdata=safe_sprintf(backdata,BUF_MAX,
-                   "URL=%s Port=%d %s"
-                   , url_data, port, URL_2);
+                  backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s" , url_data, ip_addr, port, URL_2);
                   ret = -1;
                   }
                // 受信量が正常である
@@ -278,14 +269,14 @@ if(errno == EINPROGRESS){
                   swap_mem(senddata, ',', ' ');
 
                   if(ret < 0){
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", URL_1, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"%s: %s", senddata, URL_1);
                      #ifdef URL_BUG
                      printf("URL_BUG: scan_url_connect(13): url check. not 200. ret<%d><%d> %s\n",
                        ret,*pst,backdata);
                      #endif 
                      }
                   else{
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", URL_4, senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"%s: %s", senddata, URL_4);
                      #ifdef URL_BUG
                      printf("URL_BUG: scan_url_connect(14): url check. all succesd. ret<%d><%d> %s\n",
                        ret,*pst,backdata);
@@ -293,7 +284,7 @@ if(errno == EINPROGRESS){
                      }
                   }
                // 非同期通信から同期通信に
-               fcntl(sk, F_SETFL, 0);
+//             fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
                return backdata;
@@ -313,8 +304,7 @@ if(errno == EINPROGRESS){
 // 非同期通信
 fcntl(sk, F_SETFL, 0);
 
-backdata=safe_sprintf(backdata,BUF_MAX,
- "URL=%s Port=%d %s", url_data, port, SOCK_14);
+backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s IP=%s Port=%d: %s", url_data, ip_addr, port, SOCK_14);
 #ifdef URL_BUG
 printf("URL_BUG: scan_url_connect(14): not connection err. %s\n", backdata); 
 #endif 
