@@ -157,7 +157,7 @@ printf("SSL_BUG: scanssl():\n url_data=<%s>\n url_dom=<%s>\n url_pass=<%s>\n url
 // ソケット生成
 if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
    // ソケットつくれないので離脱
-   printf("URL=%s Port=%d tcp %s\n", url_data, port, SOCK_1);
+   printf("URL %s: Port %d: %s\n", url_data, port, SOCK_1);
    #ifdef SSL_BUG
    printf("SSL_BUG: scanssl(1): NOT CLEATE SOCKETS %s\n", backdata);
    #endif
@@ -174,9 +174,10 @@ my_addr.sin_port = htons(port);
 // backdata = out_resolvename(backdata, url_dom, timeout, &resoip);
 // my_addr.sin_addr.s_addr = resoip;
 
-backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, dns_data, &resolv_ret);
+backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, dns_data, &resolv_ret, '4');
 if(resolv_ret < 0){
-   printf("DNS=<%s> %s %s\n", dns_data, SOCK_2, url_dom);
+   // 名前解決出来ないので離脱
+   printf("DNS %s: URL %s: %s\n", dns_data, url_dom, SOCK_2);
    #ifdef SSL_BUG
    fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> <%s> <%s>\n", url_dom, backdata, dns_data);
    #endif
@@ -191,8 +192,9 @@ my_addr.sin_addr.s_addr = resoip;
 
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
+   // 名前解決したIPがNULLだから離脱
 // printf("%s %s %d\n", SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr);
-   printf("%s %s\n", SOCK_2, url_dom);
+   printf("URL %s: %s\n", url_dom, SOCK_2);
    #ifdef SSL_BUG
    printf("SSL_BUG: scanssl(2):  NOT RESOLV NAME %s\n", backdata);
    #endif
@@ -236,7 +238,7 @@ if(errno == EINPROGRESS){
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
       // select の異常終了
       if(retval < 0){
-         printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_15, SOCK_5);
+         printf("URL %s: Port %d: %s\n", url_data, port, SOCK_15);
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(4): select error BREAK- %d - %s\n", retval, backdata);
          #endif
@@ -253,7 +255,7 @@ if(errno == EINPROGRESS){
 
       // select のタイムアウト
       else if(retval == 0){
-         printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_16, SOCK_5);
+         printf("URL %s: Port %d: %s\n", url_data, port, SOCK_16);
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(5): select time out BREAK- %d - %s\n", retval, backdata);
          #endif
@@ -284,7 +286,7 @@ if(errno == EINPROGRESS){
 
    // ソケットに関するペンディングエラーを返す
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
-      printf("URL=%s Port=%d %s\n", url_data, port, SOCK_13);
+      printf("URL %s: Port %d: %s\n", url_data, port, SOCK_13);
       #ifdef SSL_BUG
       printf("SSL_BUG: scanssl(): getsockopt(7) Errors!\n");
       #endif
@@ -299,7 +301,7 @@ if(errno == EINPROGRESS){
    else{
       // エラーがある場合
       if(retval){
-         printf("URL=%s Port=%d %s: TCP %s\n", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
+         printf("URL %s: Port %d: %s: %s\n", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef SSL_BUG
          printf("SSL_BUG: scanssl(8): 1 SO_ERROR %d %s\n", retval, backdata);
          #endif
@@ -321,10 +323,10 @@ if(errno == EINPROGRESS){
          ctx = SSL_CTX_new(SSLv23_client_method());
          if( ctx == NULL ){
             // ERR_print_errors_fp(stderr);
+            printf("URL %s: Port %d: %s\n", url_data, port, "ssl_ctx object cannot be generated.");
             #ifdef SSL_BUG
             printf("SSL_BUG: scanssl(): SSL_CTX_new() failed:\n");
             #endif
-            printf("URL=%s Port=%d : %s\n", url_data, port, "ssl_ctx object cannot be generated.");
             SSL_CTX_free(ctx);
             ERR_free_strings();
             close(sk);
@@ -342,10 +344,10 @@ if(errno == EINPROGRESS){
          if( ssl == NULL ){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
+            printf("URL %s: Port %d: %s: %s\n", url_data, port, swapdata, "structure cannot be initialized.");
             #ifdef SSL_BUG
             printf("SSL_BUG: scanssl(): SSL_new() failed: %s\n", swapdata);
             #endif
-            printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "structure cannot be initialized.");
             SSL_free(ssl);
             SSL_CTX_free(ctx);
             ERR_free_strings();
@@ -364,10 +366,10 @@ if(errno == EINPROGRESS){
          if( ret == 0 ){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
+            printf("URL %s: Port %d: %s: %s\n", url_data, port, swapdata, "descriptor cannot be made.");
             #ifdef SSL_BUG
             printf("SSL_BUG: scanssl(): SSL_set_fd() failed: %s\n", swapdata);
             #endif
-            printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "descriptor cannot be made.");
             SSL_free(ssl);
             SSL_CTX_free(ctx);
             ERR_free_strings();
@@ -394,10 +396,10 @@ if(errno == EINPROGRESS){
          if( ret != 1 ){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
+            printf("URL %s: Port %d: %s: %s\n", url_data, port, swapdata, "SSL cannot be used.\n");
             #ifdef SSL_BUG
             printf("SSL_BUG: scanssl(): SSL_connect() failed: %d %s\n",ret, swapdata);
             #endif
-            printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "SSL cannot be used.\n");
             SSL_shutdown(ssl); 
             SSL_free(ssl);
             SSL_CTX_free(ctx);
@@ -620,7 +622,7 @@ if(errno == EINPROGRESS){
             backdata = verify_ssl(backdata, ssl, &sslerr);
 
             if(sslerr != 0 && sslerr != 20){
-               printf("509_verify NG: id=%d, data=%s\n", sslerr, backdata);
+               printf("509_verify NG: id %d: data %s\n", sslerr, backdata);
                #ifdef SSL_BUG
                printf("SSL_BUG: scanssl(x509_verify) NG: id=%d, data=%s\n", sslerr, backdata);
                #endif
@@ -666,9 +668,10 @@ if(errno == EINPROGRESS){
          // cert の開放
          X509_free(cert);
 
+
          // SSL 確認はここまで
 
-         backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s Port=%d %s", url_data, port, SOCK_3);
+         backdata=safe_sprintf(backdata,BUF_MAX, "URL %s: Port %d: %s", url_data, port, SOCK_3);
 
          senddata = set_request(senddata, url_dom, url_pass);
          #ifdef SSL_BUG
@@ -689,7 +692,7 @@ if(errno == EINPROGRESS){
             retval = select(sk + 1, &rfds, NULL, NULL, &tv);
             // select 異常終了
             if(retval < 0){
-               printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_15, URL_2);
+               printf("URL %s: Port %d: %s: %s\n", url_data, port, SOCK_15, URL_2);
                #ifdef SSL_BUG
                printf("SSL_BUG: scanssl(10): select error %s\n", backdata);
                #endif 
@@ -709,7 +712,7 @@ if(errno == EINPROGRESS){
                }
             // select のタイムアウト
             else if(retval == 0){
-               printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_16, URL_3);
+               printf("URL %s: Port %d: %s %s\n", url_data, port, SOCK_16, URL_3);
                #ifdef SSL_BUG
                printf("SSL_BUG: scanssl(11): select timed out %s\n", backdata); 
                #endif 
@@ -732,9 +735,10 @@ if(errno == EINPROGRESS){
                dcount = SSL_read(ssl, recvdata, (256-1));
                recvdata[dcount] = 0x00;
 
+
                // 受信量が異常
                if(dcount < 1){
-                  printf("URL=%s Port=%d %s\n", url_data, port, URL_2);
+                  printf("URL %s: Port %d: %s\n", url_data, port, URL_2);
                   // 非同期通信から同期通信に
                   fcntl(sk, F_SETFL, 0);
                   // SSL回りの開放
@@ -757,7 +761,7 @@ if(errno == EINPROGRESS){
                   swap_mem(ssl_senddata, ',', ' ');
 
                   if(ret < 0){
-                     printf("%s %s\n", URL_1, ssl_senddata);
+                     printf("%s: %s\n", ssl_senddata, URL_1);
                      #ifdef SSL_BUG
                      printf("SSL_BUG: scanssl(13): url check. not 200. ret<%d> %s\n", ret,backdata);
                      #endif 
@@ -776,7 +780,7 @@ if(errno == EINPROGRESS){
                      exit(1);
                      }
                   else{
-                     backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", URL_4, ssl_senddata);
+                     backdata = safe_sprintf(backdata, BUF_MAX,"%s: %s\n", ssl_senddata, URL_4);
                      #ifdef SSL_BUG
                      printf("SSL_BUG: scanssl(14): url check. all succesd. ret<%d> %s\n", ret, backdata);
                      #endif 
@@ -822,7 +826,7 @@ if(errno == EINPROGRESS){
 // 非同期通信
 fcntl(sk, F_SETFL, 0);
 
-backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s Port=%d %s", url_data, port, SOCK_14);
+backdata=safe_sprintf(backdata,BUF_MAX, "URL %s: Port %d: %s", url_data, port, SOCK_14);
 #ifdef SSL_BUG
 printf("SSL_BUG: scanssl(14): not connection err. %s\n", backdata); 
 #endif 
