@@ -28,9 +28,9 @@ int setup_check(void)
       gd.bf.life_los = 9;
       }
 
-#ifdef PRINT_CONF
-print_conf();
-#endif
+// #ifdef PRINT_CONF
+// print_conf();
+// #endif
 return 0;
 }
 
