@@ -27,7 +27,7 @@ pthread_mutex_t file3_mutex;
 pthread_mutex_t file4_mutex;
 pthread_mutex_t name_mutex;
 pthread_mutex_t exec_mutex;
-pthread_mutex_t popen_mutex;
+// pthread_mutex_t popen_mutex;
 pthread_mutex_t fdstat_mutex;
 pthread_mutex_t break_mutex;
 pthread_mutex_t thread_mutex;
@@ -36,6 +36,7 @@ pthread_mutex_t thread_mutex;
 // sitar main関数
 int main(int argc, char * argv[])
 {
+// struct addrinfo hints;
 int tret;
 pthread_t t1, t2, t3, t4;
 errno = 0;
@@ -50,7 +51,7 @@ pthread_mutex_init(&file3_mutex, NULL);
 pthread_mutex_init(&file4_mutex, NULL);
 pthread_mutex_init(&name_mutex, NULL);
 pthread_mutex_init(&exec_mutex, NULL);
-pthread_mutex_init(&popen_mutex, NULL);
+// pthread_mutex_init(&popen_mutex, NULL);
 pthread_mutex_init(&fdstat_mutex, NULL);
 pthread_mutex_init(&break_mutex, NULL);
 pthread_mutex_init(&thread_mutex, NULL);
@@ -84,11 +85,15 @@ gd.bf.my_pid = (int)getpid();
    fprintf(stderr,"main(): fork stpgid no chenge!");
    } 
 
+memset(&gd.ip.hints, 0, sizeof(gd.ip.hints));
+
 // サーバに接続
-if((socket_connect(&gd.ip.mygd_addr, gd.ip.port, gd.ip.ip_addr, &gd.ip.sk)) < 0){
+//if((socket_connect(&gd.ip.mygd_addr, gd.ip.port, gd.ip.ip_addr, &gd.ip.sk)) < 0){
+if((socket_connect46(&gd.ip.hints, gd.ip.ip_addr, gd.ip.port_s, &gd.ip.sk)) < 0){
    fprintf(stderr,"main(): Not connection <1> %s %d\n", gd.ip.ip_addr, gd.ip.port);
    sleep(10);
-   if((socket_connect(&gd.ip.mygd_addr, gd.ip.port2, gd.ip.ip2_addr, &gd.ip.sk)) < 0){
+// if((socket_connect(&gd.ip.mygd_addr, gd.ip.port2, gd.ip.ip2_addr, &gd.ip.sk)) < 0){
+   if((socket_connect46(&gd.ip.hints, gd.ip.ip2_addr, gd.ip.port2_s, &gd.ip.sk)) < 0){
       fprintf(stderr,"main(): Not connection <2> %s %d\n", gd.ip.ip2_addr, gd.ip.port2);
       safe_exit("main(): socket connect err exit \n");
       }
