@@ -11,6 +11,12 @@
      #include "version.h"
   #endif
 
+  #ifndef _NETDB_H
+    #include<netdb.h>
+  #endif
+
+
+
   // チューニングが必要な場合OS側の調整が必要になるかもしれません。
   // FreeBSD6,7 では vm.pmap.shpgperproc の値を調整してください。
 
@@ -144,10 +150,13 @@
      struct my_sock{
         int sk;
         int ls;
-        struct sockaddr_in mygd_addr;
+        struct addrinfo hints;
+//      struct sockaddr_in mygd_addr;
         unsigned int my_addrlen;
         char * ip_addr;                // active 
         char * ip2_addr;               /* active */
+        char * port_s;
+        char * port2_s;
         int port;
         int port2;
         }ip;
