@@ -56,7 +56,7 @@
   /* --- scan_smtpport.c --- */
   char * scan_smtp_connect(int, char *, char *, int, int *);
   char * resolvename_th(char *, char *, int, unsigned long *);
-  char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *);
+  char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *, char);
   char * out_resolvename(char *, char *, int, unsigned long *);
   unsigned long resolve_name(char *name);
   time_t cert_time_get(char * data);
@@ -82,7 +82,7 @@
   char * check_recvdata(char *, char *, int *);
   int self_check_recvdata(char *, char *);
 
-   char * scan_dns_connect(int, char *, char *, char *, int, int *);
+   char * scan_dns_connect(int, char *, char *, char *, int, int *, char);
 
 
 #endif
