@@ -44,7 +44,7 @@ data = safe_memcpy(data, "Not data Not used bufer!\n", BUF_MAX);
 // $snmp_command -n <section_name> -h <host:port> -o <OID> -t <timout>
 
 if((strlen(compath) + strlen(name) + strlen(host) + strlen(getoid) + 17) < BUF_LEN){
-   sprintf(comdata,"%s -n %s -h %s -o %s -t %d", compath, name, host, getoid, timeout);
+   sprintf(comdata,"%s -n %s -h %s -o %s -t %d 2>&-", compath, name, host, getoid, timeout);
    }
 else{
    sprintf(comdata,"/bin/true -a data_size_over_err");
