@@ -16,7 +16,7 @@
 
 extern global_data_t gd;
 
-
+// V6 対応
 
 int errdata_tok(private_data_t * pd, unsigned char * ip)
 {
@@ -41,7 +41,7 @@ if(0 < maxdel && 13 <= maxlen){
    if(20 == char_count(swapdata,',') && 20 <= strlen(swapdata)){ 
       swapdata = check_strtol(swapdata);
       #ifdef ERR_OUT
-      pthread_mutex_lock(&err_mutex);
+      safe_pthread_mutex_lock(&err_mutex);
       put_log(gd.fp.err_fd, swapdata, pd->rec.user, ip);
       pthread_mutex_unlock(&err_mutex);
       #endif
@@ -75,7 +75,7 @@ if(0 < maxdel && 13 <= maxlen){
       if(20 == char_count(swapdata,',') && 20 <= strlen(swapdata)){ 
          swapdata = check_strtol(swapdata);
          #ifdef ERR_OUT
-         pthread_mutex_lock(&err_mutex);
+         safe_pthread_mutex_lock(&err_mutex);
          put_log(gd.fp.err_fd, swapdata, pd->rec.user, ip);
          pthread_mutex_unlock(&err_mutex);
          #endif
