@@ -27,7 +27,7 @@ int fp_stat = 0;
 int count0 = 0;
 int count1 = 0;
 char chA;
-char data[2][BUF_LEN];
+char data[2][IP_LEN + 2];
 char * alllock_filename = (char *)calloc(BUF_DEFLEN, sizeof(char));
 
 ret = 0;
@@ -36,8 +36,9 @@ if((fp = fopen(neg_filename, "r+"))!=NULL){
       chA = fgetc(fp);
       switch(chA){
          case ':' : data[count0][count1] = (char)0x00;
-                    if(count0 < 2){
-                       count0++; count1 = 0;
+                    if(count0 < 1){
+                       count1 = 0;
+                       count0++;
                        }
                     break;
          case ';' : data[count0][count1] = (char)0x00;
