@@ -15,6 +15,8 @@
 #include"jpreturn.h"
 
 
+// V6 対応
+
 extern global_data_t gd;
 
 
@@ -190,14 +192,11 @@ if(0 == self_memcmp(tool, "SET")){
 
 #ifdef POSTGRES_IN
 char * pgerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
-swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s');",
+swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s');",
      "INSERT INTO errlog ",
      pgerrlog_table,
      " VALUES ",
-     chIpadd[0],
-     chIpadd[1],
-     chIpadd[2],
-     chIpadd[3],
+     chIpadd,
      pd->rec.user,
      tool,
      utime,
@@ -229,7 +228,7 @@ swap_mem(swap, (char)0x01, '\n');
 
 
 /* data insert */
-pthread_mutex_lock(&pg_mutex);
+safe_pthread_mutex_lock(&pg_mutex);
 psqlexec_datain(pd, swap);
 pthread_mutex_unlock(&pg_mutex);
 #endif
@@ -237,14 +236,11 @@ pthread_mutex_unlock(&pg_mutex);
 
 #ifdef MYSQL_IN
 char * myerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
-swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s');",
+swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s');",
      "INSERT INTO errlog ",
      myerrlog_table,
      " VALUES ",
-     chIpadd[0],
-     chIpadd[1],
-     chIpadd[2],
-     chIpadd[3],
+     chIpadd,
      pd->rec.user,
      tool,
      utime,
@@ -276,7 +272,7 @@ swap_mem(swap, (char)0x01, '\n');
 
 
 /* data insert */
-pthread_mutex_lock(&mysql_mutex);
+safe_pthread_mutex_lock(&mysql_mutex);
 mysqlexec_datain(swap);
 pthread_mutex_unlock(&mysql_mutex);
 #endif
