@@ -34,7 +34,7 @@ if(ustat == 0 && astat == 0 && cgstat != 0){
    if(stat == 1){
       ret = socket_send(gd.ms.sk[pd->rec.fdno], "200 OK client set.\n", (pd->life.life_int + pd->life.life_los + 15));
       #ifdef LOG_OUT
-      pthread_mutex_lock(&con_mutex);
+      safe_pthread_mutex_lock(&con_mutex);
       log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
         "200 OK client set.", gd.ms.inip_addr[pd->rec.fdno]);
       pthread_mutex_unlock(&con_mutex);
@@ -43,7 +43,7 @@ if(ustat == 0 && astat == 0 && cgstat != 0){
    else{
       ret = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG Not client set.\n", (pd->life.life_int + pd->life.life_los + 15));
       #ifdef LOG_OUT
-      pthread_mutex_lock(&con_mutex);
+      safe_pthread_mutex_lock(&con_mutex);
       log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
         "500 NG Not client set.", gd.ms.inip_addr[pd->rec.fdno]);
       pthread_mutex_unlock(&con_mutex);
@@ -53,7 +53,7 @@ if(ustat == 0 && astat == 0 && cgstat != 0){
 else{
    ret = socket_send(gd.ms.sk[pd->rec.fdno], "500 NG The name is different.\n", (pd->life.life_int + pd->life.life_los + 15));
    #ifdef LOG_OUT
-   pthread_mutex_lock(&con_mutex);
+   safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
      "500 NG The name is different.", gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
