@@ -30,9 +30,6 @@ int setup_check(void)
      gd.bs.life_los = 9;
      }
 
-#ifdef PRINT_CONF
-print_conf();
-#endif
 return 0;
 }
 
