@@ -32,7 +32,7 @@ char * putdata = (char *)calloc(IP_LEN, sizeof(char));
 ret = 0;
 if(ustat == 0 || astat == 0 || cgstat == 0){ 
    #ifdef LOG_OUT
-   pthread_mutex_lock(&con_mutex);
+   safe_pthread_mutex_lock(&con_mutex);
    log_out(gd.fp.con_fd, pd->rec.user, pd->rec.com, pd->rec.data,
      "version checkd.", gd.ms.inip_addr[pd->rec.fdno]);
    pthread_mutex_unlock(&con_mutex);
